@@ -3,16 +3,9 @@
 # Kmer.pm: a kmer counting module
 # Author: Lee Katz <lkatz@cdc.gov>
 
-=pod SCRIPT CATEGORIES
-
-CPAN
-
-=cut
-
-
 package Bio::Kmer;
-require 5.12.0;
-our $VERSION=0.08;
+require 5.10.0;
+our $VERSION=0.10;
 
 use strict;
 use warnings;
@@ -74,7 +67,7 @@ A module for helping with kmer analysis. The basic methods help count kmers and
 
 =over
 
-=item new
+=item Bio::Kmer->new($filename, \%options)
 
 Create a new instance of the kmer counter.  One object per file. 
 
@@ -171,7 +164,7 @@ sub count{
 
 =over
 
-=item query
+=item $kmer->query($queryString)
 
 Query the set of kmers with your own query
 
@@ -211,7 +204,7 @@ sub query{
 
 =over
 
-=item histogram
+=item $kmer->histogram()
 
 Count the frequency of kmers.
 
@@ -343,6 +336,85 @@ sub kmers{
   return \%kmer;
 }
 
+=pod
+
+=over
+
+=item $kmer->union($kmer2)
+
+Count the frequency of kmers.
+
+  Arguments: Another Bio::Kmer object
+  Returns:   List of kmers
+
+=back
+
+=cut
+
+sub union{
+  my($self,$other)=@_;
+  
+  if(!$self->_checkCompatibility($other,{verbose=>1})){
+    die;
+  }
+
+  # See what kmers are in common using hashes
+  my %union;
+  my $kmer1 = $self->kmers;
+  my $kmer2 = $other->kmers;
+  for my $kmer(keys(%{ $self->kmers }), keys(%{ $other->kmers })){
+    $union{$kmer}=1;
+  }
+
+  return [keys(%union)];
+}
+
+=pod
+
+=over
+
+=item $kmer->union($kmer2)
+
+Count the frequency of kmers.
+
+  Arguments: Another Bio::Kmer object
+  Returns:   List of kmers
+
+=back
+
+=cut
+
+sub intersection{
+  my($self,$other)=@_;
+
+  if(!$self->_checkCompatibility($other,{verbose=>1})){
+    die;
+  }
+
+  my @intersection;
+  my $kmer2 = $other->kmers;
+  for my $kmer(keys(%{ $self->kmers })){
+    if($$kmer2{$kmer}){
+      push(@intersection, $kmer);
+    }
+  }
+
+  return \@intersection;
+}
+
+# See if another Bio::Kmer is the same kind as this one.
+# Return Boolean
+sub _checkCompatibility{
+  my($self,$other,$settings)=@_;
+
+  if($self->{kmerlength} != $other->{kmerlength}){
+    warn "WARNING: kmer lengths do not match\n" if($$settings{verbose});
+    return 0;
+  }
+
+  return 1;
+}
+
 sub _countKmersPurePerlWorker{
   my($kmerlength,$seqQ)=@_; 
 
